fsmpy originally developed by:
- [GCidd](https://github.com/GCidd)
- [k-apos](https://github.com/k-apos)
- [George Papakostas](https://gpapakostas.net/)
- Machine Learning and Vision Research Group

With the initial release of the library, we hope to reach a point of a community effort and extend the list above.
